# FILE: config.tcl
# Configuration script for ../build.tcl
#
# In order to work properly, the script ../build.tcl needs the values of
# several variables to be set appropriately as a description of your 
# computing environment.  It calls on another script included in this
# distribution, ./defaults.tcl, to fill in default values for
# several of these variables.  However, that script is not yet very 
# sophisticated.  It is not able to learn everything it needs to know 
# about your computing environment on its own, and may set some default
# values incorrectly.  
#
# The definitions of configuration variable values in this file 
# (./config.tcl) override the default definitions.  Therefore, any 
# errors in the default values selected by the script ./defaults.tcl may 
# be corrected by editing this file to contain appropriate overriding 
# definitions for your computing environment.
#
#			-----
#
# This file contains several candidate definitions of values for 
# configuration variables.  These definitions have the form:
#
# Default FOO bar
#
# When active, this Tcl command would set the value of the variable
# 'FOO' to 'bar', unless the variable 'FOO' had previously been set to 
# another value.  This strategy means the first definition of a variable 
# is the one which prevails.
#
# The '#' character indicates a comment in Tcl, so none of these
# definitions is active in the distributed form of this script.
# For each variable, select an appropriate definition which describes
# your computing environment, remove the leading '# ' from that line,
# and edit the value, if necessary to make any corrections for your
# computing environment.  Specific instructions for selecting
# appropriate values are found with each variable.
#
#			-----
#
# The candidate definitions in this file are divided into two sections.
# SECTION 1 contains candidate definitions for the subset of configuration
# variables which are likely to require hand-editing.  It is recommended that
# you edit SECTION 1 before attempting to evaluate the script ../build.tcl.
# SECTION 2 contains candidate definitions for the rest of the configuration
# variables, for which default values are likely to be correct.  It is 
# recommended that you edit SECTION 2 only if editing SECTION 1 proves 
# insufficient to make ../build.tcl run successfully.  You may also edit
# SECTION 2 if you wish to exercise very fine-grained control over the 
# configuration.
#
# After this file is edited so that the script ../build.tcl can successfully
# execute and compile, link, and install the software, you will want to 
# save your configuration to be re-used by future software releases.
# Future releases of software may contain a file ./config.tcl.  When you
# unpack those future releases, your edits to ./config.tcl will be 
# overwritten, and this configuration process would need to be repeated.
# To avoid this problem, copy your edited version of file ./config.tcl 
# to ./local.tcl .  Future releases of the software will not contain a
# file by that name, so your configuration data will be safe.  (If 
# ./local.tcl already exists, someone may have already configured the 
# software.  You may not need to edit this file at all.  If further 
# configuration is required, be sure to merge the changes into ./local.tcl)  
#
#			-----
#
# MULTI PLATFORM NOTE:
# If you are using a single copy of this source code distribution on many 
# platforms, the values of these configuration variables will need to be 
# reset each time you run ../build.tcl on a different platform.  It is 
# suggested that you handle this situation by editing the file ./local.tcl 
# to contain Tcl code which not only sets values of configuration variables,
# but selects those values based on the host.  The Tcl language provides 
# conditional statments and system queries to enable this approach.
#
#			-----
#
# SPECIAL NOTE FOR WINDOWS PLATFORMS:
# Some of the values assigned to configuration variables below are file 
# system path names.  It is easier to use the '/' character as a path 
# component separator than the traditional '\' from DOS.  Tcl uses '\' as
# an escape character, so if you choose to use '\' in your Windows path 
# names, you'll need to double the '\' character everywhere it appears.  
# If you use '/' instead, the necessary translation will be handled by Tcl.
#
#			-----
#
# Here are the variable definitions to edit:
########################################################################
# SECTION 1 -- Variables which you should edit
########################################################################
# ------------- Compiler/Linker configuration
#
# The build script needs to know how to run your compiler and linker programs.
#
# -------------
# Set CCC to the command used to invoke a C++ compiler on your computer.
#
#	NOTE:	If you select a compiler not listed below, you may need
#		to edit the "Compiler/Linker configuration" part of
#		SECTION 2 to describe its interface.  Try the defaults
#		first.
#
# ---
# Default CCC "CC"
# Default CCC "gcc"
# Default CCC "cl"
# -------------
# ------------- Tcl/Tk configuration
#
# The build script needs to know how/where Tcl/Tk is installed on your
# computer.
#
# -------------
# Set TCLINCLUDEDIRECTORY to the name of the directory which contains the
# Tcl header file "tcl.h" on your computer.
# ---
# Default TCLINCLUDEDIRECTORY "/usr/local/include"
# Default TCLINCLUDEDIRECTORY "/tcl/include"
# Default TCLINCLUDEDIRECTORY "/Program Files/Tcl/include"
# -------------
# Set TKINCLUDEDIRECTORY to the name of the directory which contains the
# Tk header file "tk.h" on your computer.
# ---
# Default TKINCLUDEDIRECTORY "/usr/local/include"
# Default TKINCLUDEDIRECTORY "/tcl/include"
# Default TKINCLUDEDIRECTORY "/Program Files/Tcl/include"
# -------------
# Set TCLLIBRARYDIRECTORY to the name of the directory which contains
# the Tcl library against which to link.
# ---
# Default TCLLIBRARYDIRECTORY "/usr/local/lib"
# Default TCLLIBRARYDIRECTORY "/tcl/bin"
# Default TCLLIBRARYDIRECTORY "/Program Files/Tcl/lib"
# -------------
# Set TKLIBRARYDIRECTORY to the name of the directory which contains
# the Tk library against which to link.
# ---
# Default TKLIBRARYDIRECTORY "/usr/local/lib"
# Default TKLIBRARYDIRECTORY "/tcl/bin"
# Default TKLIBRARYDIRECTORY "/Program Files/Tcl/lib"
# -------------
# Set TCLLIBRARYFILE to the name of the file (no directory part) which 
# contains the Tcl library against which to link.
#
#	NOTE:	$tcl_version will be replaced with the version of your
#		Tcl interpreter (the one evaluating this script), i.e.
#		a value such as "7.6".
# ---
# Default TCLLIBRARYFILE "libtcl.a"
# Default TCLLIBRARYFILE "libtcl$tcl_version.a"
# Default TCLLIBRARYFILE "libtcl.so"
# Default TCLLIBRARYFILE "libtcl$tcl_version.so"
# Default TCLLIBRARYFILE "tcl76.lib"
# Default TCLLIBRARYFILE "tcl75.lib"
# Default TCLLIBRARYFILE "tcl80vc.lib"
# -------------
# Set TKLIBRARYFILE to the name of the file (no directory part) which 
# contains the Tk library against which to link.
# ---
# Default TKLIBRARYFILE "libtk.a"
# Default TKLIBRARYFILE "libtk4.2.so"
# Default TKLIBRARYFILE "libtk4.1.so"
# Default TKLIBRARYFILE "libtk4.0.so"
# Default TKLIBRARYFILE "libtk.so"
# Default TKLIBRARYFILE "libtk4.2.a"
# Default TKLIBRARYFILE "libtk4.1.a"
# Default TKLIBRARYFILE "libtk4.0.a"
# Default TKLIBRARYFILE "tk42.lib"
# Default TKLIBRARYFILE "tk41.lib"
# Default TKLIBRARYFILE "tk80vc.lib"
# -------------
# ------------- X11 configuration
#
# On Unix systems, the build script needs to know how/where X11 is installed
# on your computer.
#
# -------------
# If the header file X11/Xlib.h is stored on your system in a directory 
# which is not normally searched for header files 
# (eg. /usr/openwin/include on Suns) then define X11INCLUDEDIRECTORY to be 
# the name of that directory.
# ---
# Default X11INCLUDEDIRECTORY "/usr/openwin/include"
# -------------
# Set X11LIBRARYDIRECTORY to the name of the directory which contains
# the X11 library against which to link.
# ---
# Default X11LIBRARYDIRECTORY "/usr/X11/lib"
# -------------
# ------------- Installation configuration
#
# After compiling and linking the software, you will want to install
# the binaries, run-time support, and documentation.  Use these variables
# to select the installation location.
#
# -------------
# Set INSTALLROOT to the name of the directory under which to install
# the platform-independent files.  Analogous to GNU's "prefix" directory.
# ---
# Default INSTALLROOT "/usr/local/oommf"
# Default INSTALLROOT "/oommf"
# -------------
# Set INSTALLEXECROOT to the name of the directory under which to install
# the platform-dependent files, if different from INSTALLROOT.  Useful
# only on multiplatform installations.  Analogous to GNU's "exec-prefix"
# directory.
# ---
# Default INSTALLEXECROOT $INSTALLROOT
# -------------
########################################################################
# END SECTION 1
########################################################################
#
# It is possible that configuration at a finer level of detail will be
# required on your platform, or that you wish to exercise fine-grained
# control of the build script.  In either case, edit the definitions in
# SECTION 2.
#
########################################################################
# SECTION 2 -- Variables which you should only edit if necessary
########################################################################
# ------------- Platform description 
#
# The ../build.tcl needs to know what platform you are building on.
# If you evaluate ../build.tcl with Tcl 7.5 or later, the next four
# variables should have correct defaults provided by Tcl.  Edit them
# only if necessary, and with caution.
#
# -------------
# Set PLATFORM to the one of the values "unix" or "windows" which best 
# describes your platform. 
# ---
# Default PLATFORM "unix"
# Default PLATFORM "windows"
# -------------
# Set MACHINE to a string which describes the hardware architecture of your
# computer. Use lower case only.
# ---
# Default MACHINE "sun4m"
# Default MACHINE "intel"
# Default MACHINE "i486"
# -------------
# Set OS to a string which describes the operating system of your computer.
# Use lower case only.
# ---
# Default OS "sunos"
# Default OS "irix64"
# Default OS "linux"
# -------------
# Set OSVERSION to a string which described the version of the operating
# system running on your computer.  It should probably be a sequence of
# decimal numbers separated by dots (".").
# ---
# Default OSVERSION "1.2.3"
# -------------
# ------------- System-level commands
#
# The ../build.tcl needs to know what commands it should use to interact 
# with your file system.  The next four variables supply that information.
# 
# If this script is evaluated with Tcl 7.6, there is no need to supply 
# definitions for these commands.  By default, Tcl's built-in 'file'
# command will be used to interact with the file system in a portable way.
#
# For earlier versions of Tcl on a Unix platform, the default values
# will be set to invoke shell commands.  Some editing below may be necessary 
# to control the command line options given to these shell commands.
#
# For earlier versions of Tcl on a non-Unix platform, there remains a
# great challenge to find suitable values of these variables.  It is
# probably easier just to upgrade your Tcl to 7.6 , or to download 
# a binary distribution, rather than try to build from source code.
# Sorry, but I'm punting on this one for now.  I'd love to hear about 
# any successes setting values here for other platforms.  Send your story to 
# donald.porter@nist.gov .
#
# -------------
# Set MKDIR to the ***Tcl command*** used to make a new directory 
# (folder) on your version of Tcl
# ---
# Default MKDIR	"file mkdir"	;# Good for Tcl 7.6+
# Default MKDIR	"exec mkdir"	;# Good for earlier Tcls (Unix only)
# Default MKDIR	"cmd /c mkdir"	;# Possible starting point for Windows-NT ?
# -------------
# Set RM to the ***Tcl command*** used to destroy a file on your version of Tcl.
# ---
# Default RM   	"file delete"	;# Good for Tcl 7.6+
# Default RM   	"exec rm"	;# Good for earlier Tcls (Unix only)
# Default RM	"cmd /c delete"	;# Possible starting point for Windows-NT ?
# -------------
# Set MV to the ***Tcl command*** used to change the name/location of a file 
# on your version of Tcl.
# ---
# Default MV   	"file rename"	;# Good for Tcl 7.6+
# Default MV   	"exec mv"	;# Good for earlier Tcls (Unix only)
# Default MV	"cmd /c move"	;# Possible starting point for Windows-NT ?
# -------------
# Set CP to the ***Tcl command*** used to copy a file on your version of Tcl.
# ---
# Default CP   	"file copy"	;# Good for Tcl 7.6+
# Default CP   	"exec cp"	;# Good for earlier Tcls (Unix only)
# Default CP	"cmd /c copy"	;# Possible starting point for Windows-NT ?
# -------------
# ------------- Compiler/Linker configuration
#
# Based on the choice of C++ compiler stored in CCC (see SECTION 1), default 
# values for the remaining variables in this section are set.  Edit these 
# values to override the defaults, or to describe the interface of a 
# different C++ compiler.
#
# -------------
# Set CCCEXT to the extension your C++ compiler expects for files containing
# C++ source code.
# ---
# Default CCCEXT ".cc"
# Default CCCEXT ".cpp"
# -------------
# Set OBJEXT to the extension your C++ compiler appends to the object files 
# it creates.
# ---
# Default OBJEXT ".o"
# Default OBJEXT ".obj"
# -------------
# Set EXEEXT to the extension your C++ compiler appends to the executable
# files it creates.
# ---
# Default EXEEXT ""
# Default EXEEXT ".exe"
# -------------
# Set COMPILEONYLFLAG to the command line option which instructs your C++ 
# compiler to perform only compilation, no linking.
# ---
# Default COMPILEONLYFLAG "-c"
# Default COMPILEONLYFLAG "/c"
# -------------
# Set MACRODEFINEFLAG to the command line option which supplies your C++
# compiler with a macro definition when followed by a string of the form
# "MACRO=value".
# ---
# Default MACRODEFINEFLAG "-D"
# Default MACRODEFINEFLAG "/D"
# -------------
# Set INCLUDEDIRECTORYFLAG to the command line option which, when followed
# by the name of a directory, adds that directory to the path searched by
# your C++ compiler for header files.
# ---
# Default INCLUDEDIRECTORYFLAG "-I"
# Default INCLUDEDIRECTORYFLAG "/I"
# -------------
# Set DEBUGFLAG to the command line option which directs your C++ compiler
# to include debugging information for a debugger in its object files.
# ---
# Default DEBUGFLAG "-g"
# -------------
# Set STRICTWARNFLAG to the command line option which directs your C++
# compiler to issue more warning messages than it would by default.  The
# exact meaning of this flag will vary with compilers, but it should have
# the effect of making the compiler more picky about the source code.
# ---
# Default STRICTWARNFLAG "+w"
# Default STRICTWARNFLAG "-Wall"
# -------------
# Set OUTFLAG to the command line option with which the name of an output
# object file may be specified.
# ---
# Default OUTFLAG "-o "	;# Trailing space needed
# Default OUTFLAG "/Fo"	;# *NO* trailing space
# -------------
# Set LINKOUTFLAG to the command line option with which the name of an output
# executable file may be specified.
# ---
# Default LINKOUTFLAG "-o "	;# Trailing space needed
# Default LINKOUTFLAG "/link /OUT:"	;# *NO* trailing space
# -------------
# Set LIBRARYDIRECTORYFLAG to the command line option which, when followed
# by the name of a directory, adds that directory to the path searched by
# your linker for library files.
# ---
# Default LIBRARYDIRECTORYFLAG "-L"
# -------------
# Set LIBRARYFLAG to the command line option which, when followed
# by an abbreviation of a library name, links the executable being built
# against that library.
# ---
# Default LIBRARYFLAG "-l"
# -------------
# ------------- X11 configuration
#
# On Unix systems, the build script needs to know how/where X11 is installed
# on your computer.
#
# -------------
# Set X11LIBRARYFILE to the name of the file (no directory part) which 
# contains the X11 library against which to link.
# ---
# Default X11LIBRARYFILE "libX11.a"
# Default X11LIBRARYFILE "libX11.so"
# -------------
# ------------- Installation configuration
#
# After compiling and linking the software, you will want to install
# the binaries and run-time support.  Use these variables to select
# the installation location.
#
# -------------
# Set INSTALLBIN to the name of the directory in which to install
# the application binaries.
# ---
# Default INSTALLBIN "$INSTALLEXECROOT/bin"
# -------------
# Set INSTALLTCLLIB to the name of the directory in which to install
# the library of Tcl scripts which provide run-time support.
# ---
# Default INSTALLTCLLIB "$INSTALLROOT/lib"
# -------------
# Set INSTALLDEMOS to the name of the directory in which to install
# data files shipped with the applications which demonstrate their
# capabilities.
# ---
# Default INSTALLDEMOS "$INSTALLROOT/demos"
# -------------
# ------------- Miscellaneous
#
# Any other configurable values.
#
# -------------
# Set MATHLIBRARYFILE to the name of the file (no directory part) which 
# contains the standard math library against which to link.
# ---
# Default MATHLIBRARYFILE "libm.a"
# Default MATHLIBRARYFILE "libm.so"
# -------------
#
# On some platforms where the Tcl and Tk libraries are shared, they need
# to link to another library which supports dynamic linking.  Set
# DLLIBRARYFILE to the name of the file (no directory part) which 
# contains the system library which supports dynamic linking on this
# platform.
# ---
# Default DLLIBRARYFILE "libdl.so"
# -------------
#
# Set RANDOM_GENERATOR_HEADER_BLOCK to a C++ macro that
# defines the random number generator to use.  The default
# is to use random() (seeded with srandom()):
# -------------
# Default RANDOM_GENERATOR_HEADER_BLOCK {
# #define OMF_SRANDOM(seed)  srandom(seed)
# #define OMF_RANDOM()       random()
# #define OMF_RANDOM_MAX     0x7FFFFFFF
# }
# -------------
# Some systems (notably Sun+Solaris) have random() but may be
# missing the prototypes, in which case you will need to add them:
# -------------
# Default RANDOM_GENERATOR_HEADER_BLOCK {
# extern "C" {
#     long random(void);
#     void srandom(unsigned int seed);
# }
# #define OMF_SRANDOM(seed)  srandom(seed)
# #define OMF_RANDOM()       random()
# #define OMF_RANDOM_MAX     0x7FFFFFFF
# }
# -------------
# If you don't have or don't like random(), you can
# substitute a different random number generator, for
# example, rand() and srand():
# -------------
# Default RANDOM_GENERATOR_HEADER_BLOCK {
# #define OMF_SRANDOM(seed)  srand(seed)
# #define OMF_RANDOM()       rand()
# #define OMF_RANDOM_MAX     RAND_MAX
# }
#

########################################################################
# END SECTION 2
########################################################################
