/* 
 * oommfInit.c --
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include "machine.h"
#include "misc.h"
#include "oommf.h"

/* End includes */

/*
 * The following strings are Tcl scripts which define some procs used
 * by the startup script below.  It would be more convenient to have one
 * string holding all the initialization written as Tcl code, but some
 # compilers will not accept long string literals.
 */

static char preInitScript0[] =
"proc _OMF_PkgInit {} {\n\
   rename _OMF_PkgInit {}\n\
   global omf_library omf_debug\n\
   if {![info exists omf_debug]} {set omf_debug 0}\n\
   proc OMF_PackagePrefix {} {return {}}\n\
   proc OMFOOMMF_PackagePrefix {} {OMF_PackagePrefix}\n\
   proc OMF_PackageName {} {return Oommf}\n\
   global _omf_g\n\
   proc OMF_Version {} [list return $_omf_g(version)]\n\
   unset _omf_g(version)\n\
   proc OMF_PatchLevel {} [list return $_omf_g(patchLevel)]\n\
   unset _omf_g(patchLevel)\n\
   proc OMF_FileNameBase {} {string tolower [OMF_PackageName]}\n\
 }\n\
 _OMF_PkgInit";

static char preInitScript1[] =
"proc OMF_AppendUniqueExistingReadableDirectory {listref dir} {\n\
   upvar $listref list\n\
   if {[file isdirectory $dir] && [file readable $dir]} {\n\
     if {[lsearch -exact $list $dir] < 0} {\n\
       lappend list $dir\n\
     }\n\
   }\n\
 }";

static char preInitScript2[] =
"proc OMF_ListLibraryCandidates {pfx PFX} {\n\
   global omf_library env tk_library\n\
   set dirs {}\n\
   set libvar [string toupper [OMF${PFX}_PackageName]]_LIBRARY\n\
   if [info exists env($libvar)] {\n\
     OMF_AppendUniqueExistingReadableDirectory dirs $env($libvar)\n\
   }\n\
   if [info exists omf${pfx}_library] {\n\
     OMF_AppendUniqueExistingReadableDirectory dirs [set omf${pfx}_library]\n\
   }\n\
   set execname [info nameofexecutable] \n\
   set parentDir [file dirname [file dirname $execname]]\n\
   OMF_AppendUniqueExistingReadableDirectory dirs [file join $parentDir lib]\n\
   if [info exists omf_library] {\n\
     OMF_AppendUniqueExistingReadableDirectory dirs $omf_library\n\
   }\n\
# Restore this when version/patchlevel is in directory names\n\
#   if [string match {*[ab]*} [OMF${PFX}_PatchLevel]] {\n\
#     set lib [OMF${PFX}_FileNameBase][OMF${PFX}_PatchLevel]\n\
#   } else {\n\
#     set lib [OMF${PFX}_FileNameBase][OMF${PFX}_Version]\n\
#   }\n\
# Use this instead for now\n\
   set lib [OMF${PFX}_FileNameBase]\n\
#\n\
   OMF_AppendUniqueExistingReadableDirectory dirs \\\n\
     [file join [file dirname $parentDir] $lib library]\n\
   if [info exists omf_library] {\n\
     OMF_AppendUniqueExistingReadableDirectory dirs [file join \\\n\
       [file dirname [file dirname $omf_library]] $lib library]\n\
   }\n\
   if {[info exists tk_library]} {\n\
   OMF_AppendUniqueExistingReadableDirectory dirs [file dirname $tk_library]\n\
   }\n\
   OMF_AppendUniqueExistingReadableDirectory dirs \\\n\
     [file dirname [info library]]\n\
   return $dirs\n\
 }";

/*
 * The following string is the startup script executed in new
 * interpreters.  It looks on disk in several different directories
 * for a script "oommf.tcl" that is compatible with this version
 * of OOMMF.  The oommf.tcl script does all of the real work of
 * initialization.
 */

static char initScript[] =
"proc _OMF_Init {} {\n\
   rename _OMF_Init {}\n\
   proc OMF_SourceInitScript {pfx} {\n\
     global omf${pfx}_library errorInfo\n\
     set PFX [string toupper $pfx]\n\
     set dirs [OMF_ListLibraryCandidates $pfx $PFX]\n\
     set errors \"\"\n\
     foreach i $dirs {\n\
       set omf${pfx}_library $i\n\
       set omf${pfx}file [file join $i\\\n\
           [OMF${PFX}_FileNameBase][OMF${PFX}_Version]\\\n\
           [OMF${PFX}_FileNameBase].tcl]\n\
       if {[interp issafe] || [file exists [set omf${pfx}file]]} {\n\
         if {![catch {uplevel #0 [list source [set omf${pfx}file]]} msg]} {\n\
           return\n\
         } else {\n\
           append errors \"[set omf${pfx}file]:\n\t$msg\n\n$errorInfo\n\n\"\n\
         }\n\
       }\n\
     }\n\
     set libvar [string toupper [OMF${PFX}_PackageName]]_LIBRARY\n\
     set msg \"[OMF${PFX}_PackageName] initialization failure.\n\n\"\n\
     append msg \"Can't find a usable initialization script, \"\n\
     append msg \"[file join [OMF${PFX}_FileNameBase][OMF${PFX}_Version] \\\n\
                             [OMF${PFX}_FileNameBase].tcl],\n\"\n\
     append msg \"in the following directories:\n\n\"\n\
     append msg \"[join $dirs {\n}]\n\n\"\n\
     append msg \"[OMF${PFX}_PackageName] probably hasn't been \"\n\
     append msg \"installed properly.\n\n\"\n\
     append msg \"Either (re-)install [OMF${PFX}_PackageName], \"\n\
     append msg \"or set the environment variable \"\n\
     append msg \"$libvar\nto the name \"\n\
     append msg \"of a directory containing  an error-free \"\n\
     append msg \"[file join [OMF${PFX}_FileNameBase][OMF${PFX}_Version] \\\n\
                             [OMF${PFX}_FileNameBase].tcl]. \"\n\
     append msg \"\n\nError details:\n\"\n\
     append msg \"---------------------------\n\"\n\
     append msg \"$errors\"\n\
     error $msg\n\
   }\n\
   OMF_SourceInitScript {}\n\
}\n\
_OMF_Init";

/*
 *----------------------------------------------------------------------
 *
 * Oommf_Init --
 *
 * Results:
 *	Returns a standard Tcl result.  Leaves an error message or result
 *	in interp->result.
 *
 * Side effects:
 *	Sets standard global variables for the Oommf package.
 *	Runs "oommf.tcl" script.
 *
 *----------------------------------------------------------------------
 */

int
Oommf_Init(Tcl_Interp *interp)
{
  CHAR buf[SCRATCH_BUF_SIZE];

#ifndef DEBUGLVL
#define DEBUGLVL 0         // Safety
#endif 

  // Copy preprocessor macro DEBUGLVL to Tcl variable of the same name
  sprintf(buf,"%d",DEBUGLVL);
  Tcl_SetVar(interp,"DEBUGLVL",buf,TCL_GLOBAL_ONLY);

  // Copy preprocessor macro OMF_SHELL to Tcl variable of the same name
  sprintf(buf,"%s",OMF_SHELL);
  Tcl_SetVar(interp,"omf_shell",buf,TCL_GLOBAL_ONLY);

  // Make Tcl build version available
  Tcl_SetVar(interp,"omfTclBuildVersion",TCL_PATCH_LEVEL,TCL_GLOBAL_ONLY);

  // Define the standard procs and global variables of the package
  //	The first few from macros...
    Tcl_SetVar2(interp, "_omf_g", "patchLevel", 
                        OOMMF_PATCH_LEVEL, TCL_GLOBAL_ONLY);
    Tcl_SetVar2(interp, "_omf_g", "version", 
                        OOMMF_VERSION, TCL_GLOBAL_ONLY);

    // Initialize globals in misc.cc
    omfInterp=interp;
    Omf_SetPatchLevel(interp,Omf_RunningTclPatchLevel);
#if DEBUGLVL>9
    fprintf(stderr,"RUNNING TCL VERSION: %d.%d.%d.%d\n",
	    Omf_RunningTclPatchLevel.major,
	    Omf_RunningTclPatchLevel.minor,
	    Omf_RunningTclPatchLevel.level,
	    Omf_RunningTclPatchLevel.serial);
#endif // DEBUGLVL>9

    // Make some preparations for the initialization script
    if (Tcl_Eval(interp, preInitScript0) != TCL_OK) {
      return TCL_ERROR;
    }
    if (Tcl_Eval(interp, preInitScript1) != TCL_OK) {
      return TCL_ERROR;
    }
    if (Tcl_Eval(interp, preInitScript2) != TCL_OK) {
      return TCL_ERROR;
    }

    // Evaluate an initialization script
    if (Tcl_Eval(interp, initScript) != TCL_OK) {
      return TCL_ERROR;
    }

    return TCL_OK;
}

